==> json-sql-0.1.2.tgz: package/lib/dialects/base/conditions.js <==
'use strict';

var _ = require('underscore');

// Compare conditions (e.g. $eq, $gt)
function buildCompareCondition(builder, field, operator, value) {
	var placeholder;

	// if value is object, than make field block from it
	if (value && _.isObject(value)) {
		placeholder = builder.buildBlock('field', value);
	} else {
		// if value is simple - create placeholder for it
		placeholder = builder.pushValue(value);
	}

	return [field, operator, placeholder].join(' ');
}

// Contain conditions ($in/$nin)
function buildContainsCondition(builder, field, operator, value) {
	var newValue;

	if (_.isArray(value)) {
		newValue = '(' + _(value).map(function(item) {
			return builder.pushValue(item);
		}).join(', ') + ')';
	} else if (_.isObject(value) && 'select' in value) {
		newValue = builder.buildBlock('select', value);
	} else {
		throw new Error('Invalid "' + operator + '" value type "' + typeof value + '".');
	}

	return [field, operator, newValue].join(' ');
}

module.exports = function(dialect) {
	dialect.conditions.add('$eq', function(field, operator, value) {
		return buildCompareCondition(this, field, '=', value);
	});

	dialect.conditions.add('$ne', function(field, operator, value) {
		return buildCompareCondition(this, field, '!=', value);
	});

	dialect.conditions.add('$gt', function(field, operator, value) {
		return buildCompareCondition(this, field, '>', value);
	});

	dialect.conditions.add('$lt', function(field, operator, value) {
		return buildCompareCondition(this, field, '<', value);
	});

	dialect.conditions.add('$gte', function(field, operator, value) {
		return buildCompareCondition(this, field, '>=', value);
	});

	dialect.conditions.add('$lte', function(field, operator, value) {
		return buildCompareCondition(this, field, '<=', value);
	});

	dialect.conditions.add('$is', function(field, operator, value) {
		return buildCompareCondition(this, field, 'is', value);
	});

	dialect.conditions.add('$isnot', function(field, operator, value) {
		return buildCompareCondition(this, field, 'is not', value);
	});

	dialect.conditions.add('$like', function(field, operator, value) {
		return buildCompareCondition(this, field, 'like', value);
	});

	dialect.conditions.add('$null', function(field, operator, value) {
		return buildCompareCondition(this, field, 'is' + (value ? '' : ' not'), null);
	});

	dialect.conditions.add('$field', function(field, operator, value) {
		var placeholder;

		// if value is object, than make field block from it
		if (_.isObject(value)) {
			placeholder = this.buildBlock('field', value);
		} else {
			// $field - special operator, that not make placeholder for value
			placeholder = value;
		}

		return [field, '=', placeholder].join(' ');
	});


	dialect.conditions.add('$in', function(field, operator, value) {
		return buildContainsCondition(this, field, 'in', value);
	});

	dialect.conditions.add('$nin', function(field, operator, value) {
		return buildContainsCondition(this, field, 'not in', value);
	});

	dialect.conditions.add('$between', function(field, operator, value) {
		if (!_.isArray(value)) {
			throw new Error('Invalid "between" value type "' + typeof value + '".');
		}

		if (value.length < 2) {
			throw new Error('"between" array length should be 2 or great.');
		}

		var placeholder1 = this.pushValue(value[0]);
		var placeholder2 = this.pushValue(value[1]);

		return [field, 'between', placeholder1, 'and', placeholder2].join(' ');
	});
};

==> json-sql-0.1.3.tgz: package/lib/dialects/base/conditions.js <==
'use strict';

var _ = require('underscore');

// Compare conditions (e.g. $eq, $gt)
function buildCompareCondition(builder, field, operator, value) {
	var placeholder;

	// if value is object, than make field block from it
	if (value && _.isObject(value)) {
		placeholder = builder.buildBlock('field', value);
	} else {
		// if value is simple - create placeholder for it
		placeholder = builder._pushValue(value);
	}

	return [field, operator, placeholder].join(' ');
}

// Contain conditions ($in/$nin)
function buildContainsCondition(builder, field, operator, value) {
	var newValue;

	if (_.isArray(value)) {
		newValue = '(' + _(value).map(function(item) {
			return builder._pushValue(item);
		}).join(', ') + ')';
	} else if (_.isObject(value) && 'select' in value) {
		newValue = builder.buildBlock('select', value);
	} else {
		throw new Error('Invalid "' + operator + '" value type "' + typeof value + '".');
	}

	return [field, operator, newValue].join(' ');
}

module.exports = function(dialect) {
	dialect.conditions.add('$eq', function(field, operator, value) {
		return buildCompareCondition(this, field, '=', value);
	});

	dialect.conditions.add('$ne', function(field, operator, value) {
		return buildCompareCondition(this, field, '!=', value);
	});

	dialect.conditions.add('$gt', function(field, operator, value) {
		return buildCompareCondition(this, field, '>', value);
	});

	dialect.conditions.add('$lt', function(field, operator, value) {
		return buildCompareCondition(this, field, '<', value);
	});

	dialect.conditions.add('$gte', function(field, operator, value) {
		return buildCompareCondition(this, field, '>=', value);
	});

	dialect.conditions.add('$lte', function(field, operator, value) {
		return buildCompareCondition(this, field, '<=', value);
	});

	dialect.conditions.add('$is', function(field, operator, value) {
		return buildCompareCondition(this, field, 'is', value);
	});

	dialect.conditions.add('$isnot', function(field, operator, value) {
		return buildCompareCondition(this, field, 'is not', value);
	});

	dialect.conditions.add('$like', function(field, operator, value) {
		return buildCompareCondition(this, field, 'like', value);
	});

	dialect.conditions.add('$null', function(field, operator, value) {
		return buildCompareCondition(this, field, 'is' + (value ? '' : ' not'), null);
	});

	dialect.conditions.add('$field', function(field, operator, value) {
		var placeholder;

		// if value is object, than make field block from it
		if (_.isObject(value)) {
			placeholder = this.buildBlock('field', value);
		} else {
			// $field - special operator, that not make placeholder for value
			placeholder = value;
		}

		return [field, '=', placeholder].join(' ');
	});


	dialect.conditions.add('$in', function(field, operator, value) {
		return buildContainsCondition(this, field, 'in', value);
	});

	dialect.conditions.add('$nin', function(field, operator, value) {
		return buildContainsCondition(this, field, 'not in', value);
	});

	dialect.conditions.add('$between', function(field, operator, value) {
		if (!_.isArray(value)) {
			throw new Error('Invalid "between" value type "' + typeof value + '".');
		}

		if (value.length < 2) {
			throw new Error('"between" array length should be 2 or great.');
		}

		var placeholder1 = this._pushValue(value[0]);
		var placeholder2 = this._pushValue(value[1]);

		return [field, 'between', placeholder1, 'and', placeholder2].join(' ');
	});
};
